==> gettext-tools-0.25-ia64-1.txz: install/doinst.sh <==
( cd usr/doc/gettext-tools-0.25 ; rm -rf ABOUT-NLS )
( cd usr/doc/gettext-tools-0.25 ; ln -sf /usr/share/gettext/ABOUT-NLS ABOUT-NLS )
( cd usr/lib ; rm -rf libgettextlib.so )
( cd usr/lib ; ln -sf libgettextlib-0.25.so libgettextlib.so )
( cd usr/lib ; rm -rf libgettextpo.so )
( cd usr/lib ; ln -sf libgettextpo.so.0.5.14 libgettextpo.so )
( cd usr/lib ; rm -rf libgettextpo.so.0 )
( cd usr/lib ; ln -sf libgettextpo.so.0.5.14 libgettextpo.so.0 )
( cd usr/lib ; rm -rf libgettextsrc.so )
( cd usr/lib ; ln -sf libgettextsrc-0.25.so libgettextsrc.so )
( cd usr/share/gettext/m4 ; rm -rf build-to-host.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/build-to-host.m4 build-to-host.m4 )
( cd usr/share/gettext/m4 ; rm -rf gettext.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/gettext.m4 gettext.m4 )
( cd usr/share/gettext/m4 ; rm -rf host-cpu-c-abi.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/host-cpu-c-abi.m4 host-cpu-c-abi.m4 )
( cd usr/share/gettext/m4 ; rm -rf iconv.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/iconv.m4 iconv.m4 )
( cd usr/share/gettext/m4 ; rm -rf intlmacosx.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/intlmacosx.m4 intlmacosx.m4 )
( cd usr/share/gettext/m4 ; rm -rf lib-ld.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/lib-ld.m4 lib-ld.m4 )
( cd usr/share/gettext/m4 ; rm -rf lib-link.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/lib-link.m4 lib-link.m4 )
( cd usr/share/gettext/m4 ; rm -rf lib-prefix.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/lib-prefix.m4 lib-prefix.m4 )
( cd usr/share/gettext/m4 ; rm -rf nls.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/nls.m4 nls.m4 )
( cd usr/share/gettext/m4 ; rm -rf po.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/po.m4 po.m4 )
( cd usr/share/gettext/m4 ; rm -rf progtest.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/progtest.m4 progtest.m4 )

==> gettext-tools-0.25.1-ia64-1.txz: install/doinst.sh <==
( cd usr/doc/gettext-tools-0.25.1 ; rm -rf ABOUT-NLS )
( cd usr/doc/gettext-tools-0.25.1 ; ln -sf /usr/share/gettext/ABOUT-NLS ABOUT-NLS )
( cd usr/lib ; rm -rf libgettextlib.so )
( cd usr/lib ; ln -sf libgettextlib-0.25.1.so libgettextlib.so )
( cd usr/lib ; rm -rf libgettextpo.so )
( cd usr/lib ; ln -sf libgettextpo.so.0.5.14 libgettextpo.so )
( cd usr/lib ; rm -rf libgettextpo.so.0 )
( cd usr/lib ; ln -sf libgettextpo.so.0.5.14 libgettextpo.so.0 )
( cd usr/lib ; rm -rf libgettextsrc.so )
( cd usr/lib ; ln -sf libgettextsrc-0.25.1.so libgettextsrc.so )
( cd usr/share/gettext/m4 ; rm -rf build-to-host.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/build-to-host.m4 build-to-host.m4 )
( cd usr/share/gettext/m4 ; rm -rf gettext.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/gettext.m4 gettext.m4 )
( cd usr/share/gettext/m4 ; rm -rf host-cpu-c-abi.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/host-cpu-c-abi.m4 host-cpu-c-abi.m4 )
( cd usr/share/gettext/m4 ; rm -rf iconv.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/iconv.m4 iconv.m4 )
( cd usr/share/gettext/m4 ; rm -rf intlmacosx.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/intlmacosx.m4 intlmacosx.m4 )
( cd usr/share/gettext/m4 ; rm -rf lib-ld.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/lib-ld.m4 lib-ld.m4 )
( cd usr/share/gettext/m4 ; rm -rf lib-link.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/lib-link.m4 lib-link.m4 )
( cd usr/share/gettext/m4 ; rm -rf lib-prefix.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/lib-prefix.m4 lib-prefix.m4 )
( cd usr/share/gettext/m4 ; rm -rf nls.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/nls.m4 nls.m4 )
( cd usr/share/gettext/m4 ; rm -rf po.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/po.m4 po.m4 )
( cd usr/share/gettext/m4 ; rm -rf progtest.m4 )
( cd usr/share/gettext/m4 ; ln -sf ../../aclocal/progtest.m4 progtest.m4 )
